@@ -39,7 +39,6 @@ def _hash(string: str) -> str:
 
 
 def _get_hashed_username():
-
     try:
         username = getpass.getuser()
         return _hash(username)
@@ -116,6 +115,15 @@ class KedroTelemetryProjectHooks:  # pylint: disable=too-few-public-methods
     @hook_impl
     def after_context_created(self, context):
         """Hook implementation to send project statistics data to Heap"""
+        consent = _check_for_telemetry_consent(context.project_path)
+        if not consent:
+            logger.debug(
+                "Kedro-Telemetry is installed, but you have opted out of "
+                "sharing usage analytics so none will be collected.",
+            )
+            return
+
+        logger.debug("You have opted into product usage analytics.")
 
         catalog = context.catalog
         default_pipeline = pipelines.get("__default__")  # __default__
@@ -126,7 +134,6 @@ class KedroTelemetryProjectHooks:  # pylint: disable=too-few-public-methods
         project_statistics_properties = _format_project_statistics_data(
             project_properties, catalog, default_pipeline, pipelines
         )
-
         _send_heap_event(
             event_name="Kedro Project Statistics",
             identity=hashed_username,
@@ -135,7 +142,6 @@ class KedroTelemetryProjectHooks:  # pylint: disable=too-few-public-methods
 
 
 def _get_project_properties(hashed_username: str) -> Dict:
-
     hashed_package_name = _hash(PACKAGE_NAME) if PACKAGE_NAME else "undefined"
 
     return {
